summaryrefslogtreecommitdiff
path: root/tinyusb/host
diff options
context:
space:
mode:
authorhathach <[email protected]>2013-03-06 22:41:14 +0700
committerhathach <[email protected]>2013-03-06 22:41:14 +0700
commitef08654e736f751bf07dd2f062c6916ffdbe1801 (patch)
treeb97ccef4267d8021058ea8b87ff7b936d75c9234 /tinyusb/host
parent5c3bd1f8dc6811034d22d739fe05aea144aaa0b0 (diff)
add prototype for hcd_pipe(control)_close
- update test code for enum task respectively
Diffstat (limited to 'tinyusb/host')
-rw-r--r--tinyusb/host/ehci/ehci.c4
-rw-r--r--tinyusb/host/hcd.h10
-rw-r--r--tinyusb/host/usbh.c5
3 files changed, 10 insertions, 9 deletions
diff --git a/tinyusb/host/ehci/ehci.c b/tinyusb/host/ehci/ehci.c
index ee1113d99..1d415981c 100644
--- a/tinyusb/host/ehci/ehci.c
+++ b/tinyusb/host/ehci/ehci.c
@@ -274,6 +274,7 @@ pipe_handle_t hcd_pipe_open(uint8_t dev_addr, tusb_descriptor_endpoint_t const *
{
pipe_handle_t const null_handle = { .dev_addr = 0, .xfer_type = 0, .index = 0 };
+ //------------- find a free queue head -------------//
uint8_t index=0;
while( index<EHCI_MAX_QHD && ehci_data.device[dev_addr].qhd[index].used )
{
@@ -289,16 +290,15 @@ pipe_handle_t hcd_pipe_open(uint8_t dev_addr, tusb_descriptor_endpoint_t const *
if (p_endpoint_desc->bmAttributes.xfer == TUSB_XFER_BULK)
{
- //------------- insert to async list -------------//
// TODO might need to to disable async list first
list_head = get_async_head(usbh_device_info_pool[dev_addr].core_id);
}else if (p_endpoint_desc->bmAttributes.xfer == TUSB_XFER_INTERRUPT)
{
- //------------- insert to period list -------------//
// TODO might need to to disable period list first
list_head = get_period_head(usbh_device_info_pool[dev_addr].core_id);
}
+ //------------- insert to async/period list -------------//
p_qhd->next = list_head->next;
list_head->next.address = (uint32_t) p_qhd;
list_head->next.type = EHCI_QUEUE_ELEMENT_QHD;
diff --git a/tinyusb/host/hcd.h b/tinyusb/host/hcd.h
index d180d1c58..f918ca33a 100644
--- a/tinyusb/host/hcd.h
+++ b/tinyusb/host/hcd.h
@@ -77,15 +77,13 @@ void hcd_isr(uint8_t hostid);
//--------------------------------------------------------------------+
tusb_error_t hcd_pipe_control_open(uint8_t dev_addr, uint8_t max_packet_size) ATTR_WARN_UNUSED_RESULT;
tusb_error_t hcd_pipe_control_xfer(uint8_t dev_addr, tusb_std_request_t const * p_request, uint8_t data[]) ATTR_WARN_UNUSED_RESULT;
+tusb_error_t hcd_pipe_control_close(uint8_t dev_addr) ATTR_WARN_UNUSED_RESULT;
+
pipe_handle_t hcd_pipe_open(uint8_t dev_addr, tusb_descriptor_endpoint_t const * endpoint_desc) ATTR_WARN_UNUSED_RESULT;
+tusb_error_t hcd_pipe_xfer(pipe_handle_t pipe_hdl, uint8_t buffer[]) ATTR_WARN_UNUSED_RESULT;
+tusb_error_t hcd_pipe_close(pipe_handle_t pipe_hdl) ATTR_WARN_UNUSED_RESULT;
#if 0
-//tusb_error_t hcd_pipe_open(
-// uint8_t hostid, uint8_t device_address,
-//
-// )ATTR_WARN_UNUSED_RESULT;
-tusb_error_t hcd_pipe_close()ATTR_WARN_UNUSED_RESULT;
-tusb_error_t hcd_pipe_transfer()ATTR_WARN_UNUSED_RESULT;
tusb_error_t hcd_pipe_cancel()ATTR_WARN_UNUSED_RESULT;
#endif
diff --git a/tinyusb/host/usbh.c b/tinyusb/host/usbh.c
index 794074f86..3c2010c06 100644
--- a/tinyusb/host/usbh.c
+++ b/tinyusb/host/usbh.c
@@ -173,12 +173,15 @@ OSAL_TASK_DECLARE(usbh_enumeration_task)
)
);
//------------- update port info & open control pipe for new address -------------//
usbh_device_info_pool[new_addr].core_id = usbh_device_info_pool[0].core_id;
usbh_device_info_pool[new_addr].hub_addr = usbh_device_info_pool[0].hub_addr;
usbh_device_info_pool[new_addr].hub_port = usbh_device_info_pool[0].hub_port;
usbh_device_info_pool[new_addr].speed = usbh_device_info_pool[0].speed;
usbh_device_info_pool[new_addr].status = TUSB_DEVICE_STATUS_ADDRESSED;
+ hcd_pipe_control_close(0);
+
+ // open control pipe for new address
TASK_ASSERT_STATUS ( hcd_pipe_control_open(new_addr, ((tusb_descriptor_device_t*) enum_data_buffer)->bMaxPacketSize0 ) );
//------------- Get full device descriptor -------------//
@@ -173,12 +173,15 @@ OSAL_TASK_DECLARE(usbh_enumeration_task)
)
);
- //------------- update port info & open control pipe for new address -------------//
+ //------------- update port info & close control pipe of addr0 -------------//
usbh_device_info_pool[new_addr].core_id = usbh_device_info_pool[0].core_id;
usbh_device_info_pool[new_addr].hub_addr = usbh_device_info_pool[0].hub_addr;